@@ -67,7 +67,7 @@ sub install {
     `tar xzvf $file`;
 
     print "Installing libraries to $prefix\n";
-    chdir join '-', $release->distribution->name, $release->version;
+    chdir $release->srcdir;
     `cp -r lib/* $prefix`;
 
     chdir $pwd;
@@ -116,6 +116,8 @@ JSAN::Shell -- JavaScript Archive Network (JSAN) Shell Backend
 
 Casey West <F<casey@geeknest.com>>.
 
+Adam Kennedy <F<adam@ali.as>>, L<http://ali.as>
+
 =head1 COPYRIGHT
 
   Copyright (c) 2005 Casey West.  All rights reserved.
